@@ -26,17 +26,6 @@ class LabeledScale(SmartWidget):
       # = Step = #
       self.__step = kw.get("step", 1)
       
-      storage = self._getValueStorage()
-      
-      if "" in storage:
-         self.getRawValue().set(storage.pop(""))
-      
-      else:
-         for data in zip(range(2), ("from_", "to")):
-            kw["range"][data[0]] = StaticUtils.setIfAbsentAndGet(storage, data[1], kw["range"][data[0]])
-         
-         self.getRawValue().set(StaticUtils.setIfAbsentAndGet(storage, "value", (kw["range"][0] if valueIsNone else self.getValue()) // self.__step))
-      
       # = Caption = #
       self.__caption = Label(master, text = kw["text"])
       self.__value = Label(master, anchor = E)
@@ -44,6 +33,18 @@ class LabeledScale(SmartWidget):
       # = Scale = #
       self.getRawValue().trace_add("write", self.onChanged)
       
+      storage = self._getValueStorage()
+      
+      if "" in storage:
+         self.getRawValue().set(storage.pop(""))
+      
+      else:
+         for index, key in enumerate(("from_", "to")):
+            if key in storage:
+               kw["range"][index] = storage[key]
+         
+         self.getRawValue().set(StaticUtils.setIfAbsentAndGet(storage, "value", (kw["range"][0] if valueIsNone else self.getValue()) // self.__step))
+      
       from_, to = tuple(v // self.__step for v in kw["range"])
       
       self.__scale = Scale(
@@ -100,7 +101,7 @@ class LabeledScale(SmartWidget):
       self.__setValueWidth()
    
    def setTo(self, to):
-      self.__scale["to"] = to // self._step
+      self.__scale["to"] = to // self.__step
       self._getValueStorage()["to"] = to
       
       if self.getValue() > self.__scale["to"]:
